#!/bin/bash

## Script to delete Ranger Groups from database
## Usage: deleteGroup.sh -f input.txt -u ranger_user -p password -h localhost:1521/XE
##    -f       contains newline separated list of groups to be deleted
##    -u       db user name
##    -p       db user password
##    -h       host name or ip with port and service name


usage() {
  [ "$*" ] && echo "$0: $*"
  sed -n '/^##/,/^$/s/^## \{0,1\}//p' "$0"
  exit 2
} 2>/dev/null


while [ "$1" != "" ]; do
    case $1 in
        -f | --file )           shift
                                filename=$1
                                ;;
        -u | --username )		shift
								user=$1
                                ;;
        -p | --password )		shift
								passwd=$1
                                ;;
        -h | --host )            shift
								host=$1
								;;
        -h | --help )           usage
                                exit
                                ;;
        * )                     usage
                                exit 1
    esac
    shift
done

if [ -z "$filename" ];	then	usage; exit 1; fi 
if [ -z "$user" ];		then	usage; exit 1; fi 
if [ -z "$passwd" ];	then	usage; exit 1; fi 
if [ -z "$host" ];	then	usage; exit 1; fi 
oracle_cmd="sqlplus -L -S ${user}"/"\"${passwd}\""@"${host}"
$oracle_cmd  <<EOF
CREATE OR REPLACE PROCEDURE SP_DELETE_RANGER_GROUP(grpName IN varchar2)
IS
grpId NUMBER(20);
BEGIN
	grpId := 0;
	select id into grpId from x_group where lower(group_name)=lower(grpName);
	if(grpId > 0) then
		delete from x_audit_map where group_id = grpId;
		delete from x_group_users where p_group_id = grpId;
		delete from x_perm_map where group_id = grpId;
		delete from x_group_groups where group_id = grpId or p_group_id = grpId;
		delete from x_group where id = grpId;
		commit;
	end if;
EXCEPTION
	WHEN no_data_found THEN
		DBMS_OUTPUT.PUT_LINE ('Group not found:' || grpName);
	WHEN others THEN
		DBMS_OUTPUT.PUT_LINE ('Exception:' || SQLERRM);
END;
/
EOF

while read line
do
    name=$(echo $line)
	if [ -z "$name" ]; then	continue; fi
		name=$(echo "$name" | sed "s|\\\0|\\\\\\0|g")
		name=$(echo "$name" | sed "s|'|\\\'|g")
		name=$(echo "$name" | sed "s|%|\\\%|g")
		name=$(echo "$name" | sed "s|\\\_|\\\\\\\_|g")
		name=$(echo "$name" | sed "s|Z|\\\Z|g")
    echo "  Deleting group : $name"
    sql_stmt="EXEC SP_DELETE_RANGER_GROUP('${name}');"
    result1=`${oracle_cmd} <<< ${sql_stmt}`
done < $filename
result1=`$oracle_cmd <<< "DROP PROCEDURE SP_DELETE_RANGER_GROUP;"`
echo "Deleted all Groups successfully"
