#!/bin/bash
## Script to delete Ranger Users from database
## Usage: deleteUser.sh -f input.txt -u ranger_user -p password -h localhost:1521/XE [-r <replaceUser>]
##    -f       contains newline separated list of users to be deleted
##    -u       db user name
##    -p       db user password
##    -h       host name or ip with port and service name
##    -r       (optional) User to be used to replace references of deleted user. If not provided, `admin` will be used.

superuser="admin";

usage() {
  [ "$*" ] && echo "$0: $*"
  sed -n '/^##/,/^$/s/^## \{0,1\}//p' "$0"
  exit 2
} 2>/dev/null


while [ "$1" != "" ]; do
    case $1 in
        -f | --file )           shift
                                filename=$1
                                ;;
        -u | --username )		shift
								user=$1
                                ;;
        -p | --password )		shift
								passwd=$1
                                ;;
        -r | --replaceUser )	shift
								superuser=$1
                                ;;
        -h | --host )            shift
								host=$1
								;;
        -h | --help )           usage
                                exit
                                ;;
        * )                     usage
                                exit 1
    esac
    shift
done

if [ -z "$filename" ];	then	usage; exit 1; fi 
if [ -z "$user" ];		then	usage; exit 1; fi 
if [ -z "$passwd" ];	then	usage; exit 1; fi 
if [ -z "$host" ];	then	usage; exit 1; fi
oracle_cmd="sqlplus -L -S ${user}"/"\"${passwd}\""@"${host}"
$oracle_cmd  <<EOF
CREATE OR REPLACE PROCEDURE SP_DELETE_RANGER_USER(username IN varchar2,superuser IN varchar2)
IS
xuser_id NUMBER(20);
x_portal_user_id NUMBER(20);
superuser_id NUMBER(20);
sql_stmt VARCHAR2(1000);
userrole VARCHAR2(20):='ROLE_SYS_ADMIN';
BEGIN
	xuser_id := 0;
	select id into xuser_id from x_user where lower(user_name)=lower(username);
	if (xuser_id > 0) then
		delete from x_audit_map where user_id = xuser_id;
		delete from x_group_users where user_id = xuser_id;
		delete from x_perm_map where user_id = xuser_id;
		delete from x_policy_item_user_perm where user_id = xuser_id;
		delete from x_user where id = xuser_id;
		commit;
	end if;
	x_portal_user_id := 0;
	select id into x_portal_user_id from x_portal_user where lower(login_id)=lower(username);
	if(x_portal_user_id >0) then
		select id into superuser_id from x_portal_user where lower(login_id) = (superuser);
		if(superuser_id is null) then
			sql_stmt := 'select user_id into :1 from x_portal_user_role where upper(user_role) = UPPER(:2) and status = 1 and rownum<=1';
			EXECUTE IMMEDIATE sql_stmt USING superuser_id,userrole;
		end if;
		update x_asset set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_asset set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_audit_map set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_audit_map set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_auth_sess set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_auth_sess set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_cred_store set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_cred_store set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_group set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_group set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_group_groups set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_group_groups set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_group_users set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_group_users set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_perm_map set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_perm_map set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_policy_export_audit set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_policy_export_audit set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_portal_user set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_portal_user set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_portal_user_role set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_portal_user_role set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_resource set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_resource set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_trx_log set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_trx_log set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		update x_user set added_by_id=superuser_id where added_by_id=x_portal_user_id;
		update x_user set upd_by_id=superuser_id where upd_by_id=x_portal_user_id;
		delete from x_auth_sess where user_id = x_portal_user_id;
		delete from x_user_module_perm where user_id = x_portal_user_id;
		delete from x_portal_user_role where user_id = x_portal_user_id;
		delete from x_portal_user where id = x_portal_user_id;
		commit;
	end if;
EXCEPTION
	WHEN no_data_found THEN
		DBMS_OUTPUT.PUT_LINE ('User not found:' || username);
	WHEN others THEN
		DBMS_OUTPUT.PUT_LINE ('Exception:' || SQLERRM);
END;
/
EOF

while read line
do
    name=$(echo $line)
	if [ -z "$name" ]; then	continue; fi
		name=$(echo "$name" | sed "s|\\\0|\\\\\\0|g")
		name=$(echo "$name" | sed "s|'|\\\'|g")
		name=$(echo "$name" | sed "s|%|\\\%|g")
		name=$(echo "$name" | sed "s|\\\_|\\\\\\\_|g")
		name=$(echo "$name" | sed "s|Z|\\\Z|g")
    echo "  Deleting user : $name"
    sql_stmt="EXEC SP_DELETE_RANGER_USER('${name}','${superuser}');"
    result1=`${oracle_cmd} <<< ${sql_stmt}`
done < $filename
result1=`$oracle_cmd <<< "DROP PROCEDURE SP_DELETE_RANGER_USER;"`
echo "Deleted all Users successfully"
